==> RNBIP-1.5.1.tar.gz: RNBIP-1.5.1/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / 'README.md').read_text(encoding='utf-8')

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
        # This is the name of your project. The first time you publish this
        # package, this name will be registered for you. It will determine how
        # users can install this project, e.g.:
        #
        # $ pip install sampleproject
        #
        # And where it will live on PyPI: https://pypi.org/project/sampleproject/
        #
        # There are some restrictions on what makes a valid project name
        # specification here:
        # https://packaging.python.org/specifications/core-metadata/#name
        name='RNBIP',  # Required

        # Versions should comply with PEP 440:
        # https://www.python.org/dev/peps/pep-0440/
        #
        # For a discussion on single-sourcing the version across setup.py and the
        # project code, see
        # https://packaging.python.org/en/latest/single_source_version.html
        version='1.5.1',  # Required

        # This is a one-line description or tagline of what your project does. This
        # corresponds to the "Summary" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#summary
        description='RNBIP ISA Emulator',  # Optional

        # This is an optional longer description of your project that represents
        # the body of text which users will see when they visit PyPI.
        #
        # Often, this is the same as your README, so you can just read it in from
        # that file directly (as we have already done above)
        #
        # This field corresponds to the "Description" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#description-optional
        long_description=long_description,  # Optional

        # Denotes that our long_description is in Markdown; valid values are
        # text/plain, text/x-rst, and text/markdown
        #
        # Optional if long_description is written in reStructuredText (rst) but
        # required for plain-text or Markdown; if unspecified, "applications should
        # attempt to render [the long_description] as text/x-rst; charset=UTF-8 and
        # fall back to text/plain if it is not valid rst" (see link below)
        #
        # This field corresponds to the "Description-Content-Type" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#description-content-type-optional
        long_description_content_type='text/markdown',  # Optional (see note above)

        # This should be a valid link to your project's main homepage.
        #
    # This field corresponds to the "Home-Page" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#home-page-optional
            url='https://github.com/digital-design-snu/RNBIP',  # Optional

    # This should be your name or the name of the organization which owns the
        # project.
            author='Paul George',  # Optional

    # This should be a valid email address corresponding to the author listed
        # above.
            author_email='command.paul@gmail.com',  # Optional

    # Classifiers help users find your project by categorizing it.
        #
            # For a list of valid classifiers, see https://pypi.org/classifiers/
                classifiers=[  # Optional
                        # How mature is this project? Common values are
                        #   3 - Alpha
                        #   4 - Beta
                        #   5 - Production/Stable
                        'Development Status :: 3 - Alpha',

                        # Indicate who your project is intended for
                        'Intended Audience :: Developers',

                        # Pick your license as you wish
                        'License :: OSI Approved :: MIT License',

                        # Specify the Python versions you support here. In particular, ensure
                        # that you indicate you support Python 3. These classifiers are *not*
                        # checked by 'pip install'. See instead 'python_requires' below.
                        'Programming Language :: Python :: 3',
                        'Programming Language :: Python :: 3.6',
                        'Programming Language :: Python :: 3.7',
                        'Programming Language :: Python :: 3.8',
                        'Programming Language :: Python :: 3.9',
                        'Programming Language :: Python :: 3 :: Only',
                    ],

    # This field adds keywords for your project which will appear on the
        # project page. What does your project relate to?
            #
                # Note that this is a list of additional keywords, separated
                    # by commas, to be used to assist searching for the distribution in a
                        # larger catalog.
                            keywords='sample, setuptools, development',  # Optional

    # When your source code is in a subdirectory under the project root, e.g.
        # `src/`, it is necessary to specify the `package_dir` argument.

    # You can just specify package directories manually here if your project is
        # simple. Or you can use find_packages().
            packages = find_packages(),
                # Alternatively, if you just want to distribute a single Python file, use
                    # the `py_modules` argument instead as follows, which will expect a file
                        # called `my_module.py` to exist:
                            #
                                # py_modules=["emulator_backend","emulator_gui","emulator_io","rnbip_MainWindow_UI",
                                #             "rnbip_assembler","rnbip_emulator","RNBIP_ISA"],

    # Specify which Python versions you support. In contrast to the
        # 'Programming Language' classifiers above, 'pip install' will check this
            # and refuse to install the project if the version does not match. See
                # https://packaging.python.org/guides/distributing-packages-using-setuptools/#python-requires
                    python_requires='>=3.6, <4',

    # This field lists other packages that your project depends on to run.
        # Any package you put here will be installed by pip when your project is
            # installed, so they must be valid existing projects.
                #
                    # For an analysis of "install_requires" vs pip's requirements files see:
                        # https://packaging.python.org/en/latest/requirements.html
                            install_requires=['pyqt5'],  # Optional
    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/distutils/setupscript.html#installing-additional-files
    #
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # package_data={'rnbip_emulator': ['asset/back_final.png','asset/Capture2.png','asset/Capture3.png','asset/Capture_final.png','asset/Capture_x.png','asset/C_no.png','asset/C_yes.png','asset/Databus.png','asset/D_SP.png','asset/E_FL.png','asset/E_IP.png','asset/E_OR.png','asset/E_PC.png','asset/E_R0.png','asset/E_RN.png','asset/E_SP.png','asset/I_PC.png','asset/I_SP.png','asset/killEOR.png','asset/killEPC.png','asset/killLPC.png','asset/killLR0.png','asset/killLRN2.png','asset/L_IR.png','asset/L_OP.png','asset/L_OR.png','asset/L_PC.png','asset/L_R0.png','asset/L_RN.png','asset/L_SP.png','asset/OD_PC.png','asset/OP_no.png','asset/OP_yes.png','asset/P_no.png','asset/P_yes.png','asset/R0_AS.png','asset/RD.png','asset/SAF_activated.png','asset/S_AL.png','asset/S_IF.png','asset/S_PC.png','asset/specialPath.png','asset/S_SP.png','asset/WR.png','asset/Z_no.png','asset/Z_yes.png','machCode.bin']},
    include_package_data=True,

    # To provide executable scripts, use entry points in preference to the
        # "scripts" keyword. Entry points provide cross-platform support and allow
            # `pip` to create the appropriate form of executable for the target
                # platform.
                    #
                        # For example, the following would provide a command called `sample` which
                            # executes the function `main` from this package when invoked:
                                entry_points={  # Optional
                                    'console_scripts': [
                                                    'rnbip=rnbip_emulator:main',
                                    ],
                                    },

)

==> RNBIP-1.6.0.tar.gz: RNBIP-1.6.0/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / 'README.md').read_text(encoding='utf-8')

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
        # This is the name of your project. The first time you publish this
        # package, this name will be registered for you. It will determine how
        # users can install this project, e.g.:
        #
        # $ pip install sampleproject
        #
        # And where it will live on PyPI: https://pypi.org/project/sampleproject/
        #
        # There are some restrictions on what makes a valid project name
        # specification here:
        # https://packaging.python.org/specifications/core-metadata/#name
        name='RNBIP',  # Required

        # Versions should comply with PEP 440:
        # https://www.python.org/dev/peps/pep-0440/
        #
        # For a discussion on single-sourcing the version across setup.py and the
        # project code, see
        # https://packaging.python.org/en/latest/single_source_version.html
        version='1.6.0',  # Required

        # This is a one-line description or tagline of what your project does. This
        # corresponds to the "Summary" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#summary
        description='RNBIP ISA Emulator',  # Optional

        # This is an optional longer description of your project that represents
        # the body of text which users will see when they visit PyPI.
        #
        # Often, this is the same as your README, so you can just read it in from
        # that file directly (as we have already done above)
        #
        # This field corresponds to the "Description" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#description-optional
        long_description=long_description,  # Optional

        # Denotes that our long_description is in Markdown; valid values are
        # text/plain, text/x-rst, and text/markdown
        #
        # Optional if long_description is written in reStructuredText (rst) but
        # required for plain-text or Markdown; if unspecified, "applications should
        # attempt to render [the long_description] as text/x-rst; charset=UTF-8 and
        # fall back to text/plain if it is not valid rst" (see link below)
        #
        # This field corresponds to the "Description-Content-Type" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#description-content-type-optional
        long_description_content_type='text/markdown',  # Optional (see note above)

        # This should be a valid link to your project's main homepage.
        #
    # This field corresponds to the "Home-Page" metadata field:
        # https://packaging.python.org/specifications/core-metadata/#home-page-optional
            url='https://github.com/digital-design-snu/RNBIP',  # Optional

    # This should be your name or the name of the organization which owns the
        # project.
            author='Paul George',  # Optional

    # This should be a valid email address corresponding to the author listed
        # above.
            author_email='command.paul@gmail.com',  # Optional

    # Classifiers help users find your project by categorizing it.
        #
            # For a list of valid classifiers, see https://pypi.org/classifiers/
                classifiers=[  # Optional
                        # How mature is this project? Common values are
                        #   3 - Alpha
                        #   4 - Beta
                        #   5 - Production/Stable
                        'Development Status :: 3 - Alpha',

                        # Indicate who your project is intended for
                        'Intended Audience :: Developers',

                        # Pick your license as you wish
                        'License :: OSI Approved :: MIT License',

                        # Specify the Python versions you support here. In particular, ensure
                        # that you indicate you support Python 3. These classifiers are *not*
                        # checked by 'pip install'. See instead 'python_requires' below.
                        'Programming Language :: Python :: 3',
                        'Programming Language :: Python :: 3.6',
                        'Programming Language :: Python :: 3.7',
                        'Programming Language :: Python :: 3.8',
                        'Programming Language :: Python :: 3.9',
                        'Programming Language :: Python :: 3 :: Only',
                    ],

    # This field adds keywords for your project which will appear on the
        # project page. What does your project relate to?
            #
                # Note that this is a list of additional keywords, separated
                    # by commas, to be used to assist searching for the distribution in a
                        # larger catalog.
                            keywords='sample, setuptools, development',  # Optional

    # When your source code is in a subdirectory under the project root, e.g.
        # `src/`, it is necessary to specify the `package_dir` argument.

    # You can just specify package directories manually here if your project is
        # simple. Or you can use find_packages().
            packages = find_packages(),
                # Alternatively, if you just want to distribute a single Python file, use
                    # the `py_modules` argument instead as follows, which will expect a file
                        # called `my_module.py` to exist:
                            #
                                # py_modules=["emulator_backend","emulator_gui","emulator_io","rnbip_MainWindow_UI",
                                #             "rnbip_assembler","rnbip_emulator","RNBIP_ISA"],

    # Specify which Python versions you support. In contrast to the
        # 'Programming Language' classifiers above, 'pip install' will check this
            # and refuse to install the project if the version does not match. See
                # https://packaging.python.org/guides/distributing-packages-using-setuptools/#python-requires
                    python_requires='>=3.6, <4',

    # This field lists other packages that your project depends on to run.
        # Any package you put here will be installed by pip when your project is
            # installed, so they must be valid existing projects.
                #
                    # For an analysis of "install_requires" vs pip's requirements files see:
                        # https://packaging.python.org/en/latest/requirements.html
                            install_requires=['PyQt5'],  # Optional
    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/distutils/setupscript.html#installing-additional-files
    #
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # package_data={'rnbip_emulator': ['asset/back_final.png','asset/Capture2.png','asset/Capture3.png','asset/Capture_final.png','asset/Capture_x.png','asset/C_no.png','asset/C_yes.png','asset/Databus.png','asset/D_SP.png','asset/E_FL.png','asset/E_IP.png','asset/E_OR.png','asset/E_PC.png','asset/E_R0.png','asset/E_RN.png','asset/E_SP.png','asset/I_PC.png','asset/I_SP.png','asset/killEOR.png','asset/killEPC.png','asset/killLPC.png','asset/killLR0.png','asset/killLRN2.png','asset/L_IR.png','asset/L_OP.png','asset/L_OR.png','asset/L_PC.png','asset/L_R0.png','asset/L_RN.png','asset/L_SP.png','asset/OD_PC.png','asset/OP_no.png','asset/OP_yes.png','asset/P_no.png','asset/P_yes.png','asset/R0_AS.png','asset/RD.png','asset/SAF_activated.png','asset/S_AL.png','asset/S_IF.png','asset/S_PC.png','asset/specialPath.png','asset/S_SP.png','asset/WR.png','asset/Z_no.png','asset/Z_yes.png','machCode.bin']},
    include_package_data=True,

    # To provide executable scripts, use entry points in preference to the
        # "scripts" keyword. Entry points provide cross-platform support and allow
            # `pip` to create the appropriate form of executable for the target
                # platform.
                    #
                        # For example, the following would provide a command called `sample` which
                            # executes the function `main` from this package when invoked:
                                entry_points={  # Optional
                                    'console_scripts': [
                                                    'rnbip=rnbip_emulator:main',
                                    ],
                                    },

)
